@@ -1,9 +1,9 @@
 /*
- * tomoyo_new_test.c
+ * ccs_new_test.c
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.3.0+   2011/09/29
+ * Version: 2.5.0   2011/09/29
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -98,12 +98,13 @@ static void test_execute_bin_true(void)
 	char *envp[] = { "HOME=/", NULL };
 	int pipe_fd[2] = { EOF, EOF };
 	int err = 0;
-	pipe(pipe_fd);
+	int ret_ignored;
+	ret_ignored = pipe(pipe_fd);
 	switch (fork()) {
 	case 0:
 		execve("/bin/true", argv, envp);
 		err = errno;
-		write(pipe_fd[1], &err, sizeof(err));
+		ret_ignored = write(pipe_fd[1], &err, sizeof(err));
 		_exit(0);
 		break;
 	case -1:
@@ -111,7 +112,7 @@ static void test_execute_bin_true(void)
 		break;
 	}
 	close(pipe_fd[1]);
-	read(pipe_fd[0], &err, sizeof(err));
+	ret_ignored = read(pipe_fd[0], &err, sizeof(err));
 	close(pipe_fd[0]);
 	result = err ? EOF : 0;
 	errno = err;
@@ -293,11 +294,6 @@ static void test_file_open_19(void)
 	result = open("/tmp/testfile19", O_TRUNC | O_CREAT | O_RDWR, 0600);
 }
 
-static void test_file_open_20(void)
-{
-	result = open("/tmp/testfile20", O_APPEND | O_RDWR, 0600);
-}
-
 static void test_file_open_21(void)
 {
 	result = open("/tmp/testfile21", O_APPEND | O_CREAT | O_RDWR, 0600);
@@ -322,16 +318,10 @@ static void setup_test_file(void)
 	for (i = 0; i < 24; i += 2) {
 		snprintf(buffer, sizeof(buffer) - 1, "/tmp/testfile%u", i);
 		close(open(buffer, O_WRONLY | O_CREAT, 0600));
+		close(open(buffer, O_APPEND | O_CREAT, 0600));
 	}
-	write_exception_policy("deny_rewrite /tmp/testfile\\$", 0);
 }
 
-static void setup_test_file_truncate(void)
-{
-	setup_test_file();
-	write_domain_policy("allow_truncate /tmp/testfile\\$", 0);
-	set_profile(3, "file::truncate");
-}
 
 static void setup_all_test_file(void)
 {
@@ -341,15 +331,8 @@ static void setup_all_test_file(void)
 	for (i = 0; i < 24; i++) {
 		snprintf(buffer, sizeof(buffer) - 1, "/tmp/testfile%u", i);
 		close(open(buffer, O_WRONLY | O_CREAT, 0600));
+		close(open(buffer, O_APPEND | O_CREAT, 0600));
 	}
-	write_exception_policy("deny_rewrite /tmp/testfile\\$", 0);
-}
-
-static void setup_all_test_file_truncate(void)
-{
-	setup_all_test_file();
-	write_domain_policy("allow_truncate /tmp/testfile\\$", 0);
-	set_profile(3, "file::truncate");
 }
 
 static void cleanup_test_file(void)
@@ -361,17 +344,9 @@ static void cleanup_test_file(void)
 		snprintf(buffer, sizeof(buffer) - 1, "/tmp/testfile%u", i);
 		unlink(buffer);
 	}
-	write_exception_policy("deny_rewrite /tmp/testfile\\$", 1);
 	cleanup_file_open();
 }
 
-static void cleanup_test_file_truncate(void)
-{
-	cleanup_test_file();
-	write_domain_policy("allow_truncate /tmp/testfile\\$", 1);
-	set_profile(0, "file::truncate");
-}
-
 static struct test_struct {
 	void (*do_setup) (void);
 	void (*do_test) (void);
@@ -380,267 +355,205 @@ static struct test_struct {
 	const char *policy;
 } tests[] = {
 	{ NULL, test_read_etc_fstab, cleanup_file_open, "file::open",
-	  "allow_read /etc/fstab" },
+	  "file read /etc/fstab" },
 	{ NULL, test_read_etc_fstab, cleanup_file_open, "file::open",
-	  "allow_read /etc/fstab" },
+	  "file read /etc/fstab task.uid=0" },
 	{ NULL, test_read_etc_fstab, cleanup_file_open, "file::open",
-	  "allow_read /etc/fstab" },
+	  "file read /etc/fstab path1.uid=0 path1.parent.uid=0" },
 	{ setup_open_group, test_read_etc_fstab, cleanup_open_group,
-	  "file::open", "allow_read @READABLE" },
+	  "file::open", "file read @READABLE path1.uid=@READABLE_IDS "
+	  "path1.parent.uid=0" },
 	{ NULL, test_write_dev_null, cleanup_file_open, "file::open",
-	  "allow_write /dev/null" },
+	  "file write /dev/null" },
 	{ NULL, test_write_dev_null, cleanup_file_open, "file::open",
-	  "allow_write /dev/null" },
+	  "file write /dev/null task.uid=0" },
 	{ NULL, test_write_dev_null, cleanup_file_open, "file::open",
-	  "allow_write /dev/null" },
+	  "file write /dev/null path1.type=char path1.dev_major=1 "
+	  "path1.dev_minor=3 path1.perm=0666" },
 	{ cleanup_mkdir_testdir, test_mkdir_testdir, cleanup_mkdir_testdir,
-	  "file::mkdir", "allow_mkdir /tmp/testdir/ 0755" },
+	  "file::mkdir", "file mkdir /tmp/testdir/ 0755" },
 	{ cleanup_mkdir_testdir, test_mkdir_testdir, cleanup_mkdir_testdir,
-	  "file::mkdir", "allow_mkdir /tmp/testdir/ 0755" },
+	  "file::mkdir", "file mkdir /tmp/testdir/ 0755 "
+	  "path1.parent.uid=0 path1.parent.perm=01777" },
 	{ cleanup_mkdir_testdir, test_mkdir_testdir, cleanup_mkdir_testdir,
-	  "file::mkdir", "allow_mkdir /tmp/testdir/ 0755" },
+	  "file::mkdir", "file mkdir /tmp/testdir/ 0755 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_mkdir_testdir, test_rmdir_testdir, cleanup_mkdir_testdir,
-	  "file::rmdir", "allow_rmdir /tmp/testdir/" },
+	  "file::rmdir", "file rmdir /tmp/testdir/" },
 	{ setup_mkdir_testdir, test_rmdir_testdir, cleanup_mkdir_testdir,
-	  "file::rmdir", "allow_rmdir /tmp/testdir/" },
+	  "file::rmdir", "file rmdir /tmp/testdir/ path1.parent.uid=0 "
+	  "path1.parent.perm=01777" },
 	{ setup_mkdir_testdir, test_rmdir_testdir, cleanup_mkdir_testdir,
-	  "file::rmdir", "allow_rmdir /tmp/testdir/" },
+	  "file::rmdir", "file rmdir /tmp/testdir/ task.uid=0-100 "
+	  "task.gid=0x0-0xFF path1.uid=0" },
 	{ setup_execute_bin_true, test_execute_bin_true,
 	  cleanup_execute_bin_true, "file::execute",
-	  "allow_execute /bin/true" },
+	  "file execute /bin/true" },
 	{ setup_execute_bin_true, test_execute_bin_true,
-	  cleanup_execute_bin_true, "file::execute", "allow_execute /bin/true" },
+	  cleanup_execute_bin_true, "file::execute", "file execute /bin/true "
+	  "exec.argc=1 exec.argv[0]=\"/bin/true\"" },
 	{ setup_execute_bin_true, test_execute_bin_true,
-	  cleanup_execute_bin_true, "file::execute", "allow_execute /bin/true"
+	  cleanup_execute_bin_true, "file::execute", "file execute /bin/true "
+	  "exec.envc=1 exec.envp[\"HOME\"]=\"/\" exec.envp[\"PATH\"]=NULL"
 	},
 	{ NULL, test_chmod_dev_null, NULL, "file::chmod",
-	  "allow_chmod /dev/null 0666"
+	  "file chmod /dev/null 0666 path1.perm=00-07777 path1.type=char"
 	},
 	{ NULL, test_chown_dev_null, NULL, "file::chown",
-	  "allow_chown /dev/null 0" },
+	  "file chown /dev/null 0 task.gid=path1.gid path1.type!=block" },
 	{ NULL, test_chgrp_dev_null, NULL, "file::chgrp",
-	  "allow_chgrp /dev/null 0" },
+	  "file chgrp /dev/null 0 task.uid=path1.parent.uid" },
 	{ NULL, test_ioctl_dev_null, NULL, "file::ioctl",
-	  "allow_ioctl /dev/null 0x5451" },
+	  "file ioctl /dev/null 0x5451 0=0-1000" },
 	{ setup_chmod_group, test_chmod_dev_null, cleanup_chmod_group,
-	  "file::chmod", "allow_chmod @CHMOD_TARGET @CHMOD_MODES" },
+	  "file::chmod", "file chmod @CHMOD_TARGET @CHMOD_MODES" },
 	{ setup_chown_group, test_chown_dev_null, cleanup_chown_group,
-	  "file::chown", "allow_chown @CHOWN_TARGET @CHOWN_IDS" },
+	  "file::chown", "file chown @CHOWN_TARGET @CHOWN_IDS" },
 	{ setup_chown_group, test_chgrp_dev_null, cleanup_chown_group,
-	  "file::chgrp", "allow_chgrp @CHOWN_TARGET @CHOWN_IDS" },
+	  "file::chgrp", "file chgrp @CHOWN_TARGET @CHOWN_IDS" },
 	{ setup_ioctl_group, test_ioctl_dev_null, cleanup_ioctl_group,
-	  "file::ioctl", "allow_ioctl @IOCTL_TARGET @IOCTL_NUMBERS" },
+	  "file::ioctl", "file ioctl @IOCTL_TARGET @IOCTL_NUMBERS" },
 	{ setup_test_file, test_file_open_0, cleanup_test_file, "file::open",
-	  "allow_read /tmp/testfile0" },
+	  "file read /tmp/testfile0 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_1, cleanup_test_file, "file::open",
-	  "allow_read /tmp/testfile1" },
+	  "file read /tmp/testfile1 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_1, cleanup_test_file, "file::create",
-	  "allow_create /tmp/testfile1 0600" },
+	  "file create /tmp/testfile1 0600 task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_2, cleanup_test_file, "file::open",
-	  "allow_read /tmp/testfile2" },
+	  "file read /tmp/testfile2 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_2, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile2"
-	},
-	{ setup_test_file_truncate, test_file_open_2,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile2" },
+	  "file::truncate", "file truncate /tmp/testfile2 "
+	  "task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_3, cleanup_test_file,
-	  "file::open", "allow_read /tmp/testfile3" },
+	  "file::open", "file read /tmp/testfile3 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_3, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile3 0600"
-	},
+	  "file::create", "file create /tmp/testfile3 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_4, cleanup_test_file, "file::open",
-	  "allow_read /tmp/testfile4" },
+	  "file read /tmp/testfile4 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_5, cleanup_test_file, "file::open",
-	  "allow_read /tmp/testfile5" },
+	  "file read /tmp/testfile5 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_5, cleanup_test_file, "file::create",
-	  "allow_create /tmp/testfile5 0600" },
+	  "file create /tmp/testfile5 0600 task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_6, cleanup_test_file, "file::open",
-	  "allow_read /tmp/testfile6" },
+	  "file read /tmp/testfile6 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_6, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile6"
-	},
-	{ setup_test_file_truncate, test_file_open_6,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile6" },
+	  "file::truncate", "file truncate /tmp/testfile6 "
+	  "task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_7, cleanup_test_file, "file::open",
-	  "allow_read /tmp/testfile7" },
+	  "file read /tmp/testfile7 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_7, cleanup_test_file, "file::create",
-	  "allow_create /tmp/testfile7 0600" },
+	  "file create /tmp/testfile7 0600 task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_8, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile8" },
-	{ setup_test_file, test_file_open_8, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile8"
-	},
+	  "file write /tmp/testfile8 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_9, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile9" },
+	  "file write /tmp/testfile9 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_9, cleanup_test_file, "file::create",
-	  "allow_create /tmp/testfile9 0600" },
-	{ setup_test_file, test_file_open_9, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile9"
-	},
+	  "file create /tmp/testfile9 0600 task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_10, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile10" },
+	  "file write /tmp/testfile10 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_10, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile10"
-	},
-	{ setup_test_file, test_file_open_10, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile10"
-	},
+	  "file::truncate", "file truncate /tmp/testfile10 "
+	  "task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_11, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile11" },
+	  "file write /tmp/testfile11 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_11, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile11 0600"
-	},
-	{ setup_test_file, test_file_open_11, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile11"
-	},
+	  "file::create", "file create /tmp/testfile11 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_12, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile12" },
+	  "file append /tmp/testfile12 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_13, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile13" },
+	  "file append /tmp/testfile13 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_13, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile13 0600"
-	},
+	  "file::create", "file create /tmp/testfile13 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_14, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile14" },
+	  "file append /tmp/testfile14 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_14, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile14"
-	},
-	{ setup_test_file_truncate, test_file_open_14,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile14" },
+	  "file::truncate", "file truncate /tmp/testfile14 "
+	  "task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_15, cleanup_test_file, "file::open",
-	  "allow_write /tmp/testfile15" },
+	  "file append /tmp/testfile15 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_15, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile15 0600"
-	},
+	  "file::create", "file create /tmp/testfile15 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_16, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile16" },
-	{ setup_test_file, test_file_open_16, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile16"
-	},
+	  "file read /tmp/testfile16 task.uid=path1.uid\t"
+	  "file write /tmp/testfile16 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_17, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile17" },
+	  "file read /tmp/testfile17 task.uid=path1.uid\t"
+	  "file write /tmp/testfile17 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_17, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile17 0600"
-	},
-	{ setup_test_file, test_file_open_17, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile17"
-	},
+	  "file::create", "file create /tmp/testfile17 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_18, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile18" },
+	  "file read /tmp/testfile18 task.uid=path1.uid\t"
+	  "file write /tmp/testfile18 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_18, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile18"
-	},
-	{ setup_test_file, test_file_open_18, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile18"
-	},
+	  "file::truncate", "file truncate /tmp/testfile18 "
+	  "task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_19, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile19" },
+	  "file read /tmp/testfile19 task.uid=path1.uid\t"
+	  "file write /tmp/testfile19 task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_19, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile19 0600"
-	},
-	{ setup_test_file, test_file_open_19, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile19"
-	},
-	{ setup_test_file, test_file_open_20, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile20" },
-	{ setup_test_file, test_file_open_21, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile21" },
+	  "file::create", "file create /tmp/testfile19 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_21, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile21 0600"
-	},
-	{ setup_test_file, test_file_open_22, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile22" },
+	  "file::create", "file create /tmp/testfile21 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_test_file, test_file_open_22, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile22"
-	},
-	{ setup_test_file_truncate, test_file_open_22,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile22" },
-	{ setup_test_file, test_file_open_23, cleanup_test_file, "file::open",
-	  "allow_read/write /tmp/testfile23" },
+	  "file::truncate", "file truncate /tmp/testfile22 "
+	  "task.uid=path1.uid" },
 	{ setup_test_file, test_file_open_23, cleanup_test_file,
-	  "file::create", "allow_create /tmp/testfile23 0600"
-	},
+	  "file::create", "file create /tmp/testfile23 0600 "
+	  "task.uid=path1.parent.uid" },
 	{ setup_all_test_file, test_file_open_0, cleanup_test_file,
-	  "file::open", "allow_read /tmp/testfile0" },
+	  "file::open", "file read /tmp/testfile0 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_2, cleanup_test_file,
-	  "file::open", "allow_read /tmp/testfile2" },
+	  "file::open", "file read /tmp/testfile2 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_2, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile2"
-	},
-	{ setup_all_test_file_truncate, test_file_open_2,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile2" },
+	  "file::truncate", "file truncate /tmp/testfile2 "
+	  "task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_4, cleanup_test_file,
-	  "file::open", "allow_read /tmp/testfile4" },
+	  "file::open", "file read /tmp/testfile4 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_6, cleanup_test_file,
-	  "file::open", "allow_read /tmp/testfile6" },
+	  "file::open", "file read /tmp/testfile6 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_6, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile6"
-	},
-	{ setup_all_test_file_truncate, test_file_open_6,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile6" },
+	  "file::truncate", "file truncate /tmp/testfile6 "
+	  "task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_8, cleanup_test_file,
-	  "file::open", "allow_write /tmp/testfile8" },
-	{ setup_all_test_file, test_file_open_8, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile8"
-	},
+	  "file::open", "file write /tmp/testfile8 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_10, cleanup_test_file,
-	  "file::open", "allow_write /tmp/testfile10" },
+	  "file::open", "file write /tmp/testfile10 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_10, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile10"
-	},
-	{ setup_all_test_file, test_file_open_10, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile10"
-	},
+	  "file::truncate", "file truncate /tmp/testfile10 "
+	  "task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_12, cleanup_test_file,
-	  "file::open", "allow_write /tmp/testfile12" },
+	  "file::open", "file append /tmp/testfile12 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_14, cleanup_test_file,
-	  "file::open", "allow_write /tmp/testfile14" },
+	  "file::open", "file append /tmp/testfile14 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_14, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile14"
-	},
-	{ setup_all_test_file_truncate, test_file_open_14,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile14" },
+	  "file::truncate", "file truncate /tmp/testfile14 "
+	  "task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_16, cleanup_test_file,
-	  "file::open", "allow_read/write /tmp/testfile16"
-	},
-	{ setup_all_test_file, test_file_open_16, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile16"
-	},
+	  "file::open", "file read /tmp/testfile16 task.uid=path1.gid\t"
+	  "file write /tmp/testfile16 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_18, cleanup_test_file,
-	  "file::open", "allow_read/write /tmp/testfile18"
-	},
+	  "file::open", "file read /tmp/testfile18 task.uid=path1.gid\t"
+	  "file write /tmp/testfile18 task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_18, cleanup_test_file,
-	  "file::truncate", "allow_truncate /tmp/testfile18"
-	},
-	{ setup_all_test_file, test_file_open_18, cleanup_test_file,
-	  "file::rewrite", "allow_rewrite /tmp/testfile18"
-	},
-	{ setup_all_test_file, test_file_open_20, cleanup_test_file,
-	  "file::open",
-	  "allow_read/write /tmp/testfile20" },
-	{ setup_all_test_file, test_file_open_22, cleanup_test_file,
-	  "file::open",
-	  "allow_read/write /tmp/testfile22" },
+	  "file::truncate", "file truncate /tmp/testfile18 "
+	  "task.uid=path1.gid" },
 	{ setup_all_test_file, test_file_open_22, cleanup_test_file,
 	  "file::truncate",
-	  "allow_truncate /tmp/testfile22" },
-	{ setup_all_test_file_truncate, test_file_open_22,
-	  cleanup_test_file_truncate, "file::rewrite",
-	  "allow_rewrite /tmp/testfile22" },
+	  "file truncate /tmp/testfile22 task.uid=path1.gid" },
 	{ NULL }
 };
 
 int main(int argc, char *argv[])
 {
 	int i;
-	tomoyo_test_init();
+	ccs_test_init();
 	for (i = 0; tests[i].do_test; i++) {
 		int trial;
 		for (trial = 0; trial < 2; trial++) {
