@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.4.0+   2011/09/29
+ * Version: 2.5.0   2011/09/29
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -281,7 +281,10 @@ struct ccs_editpolicy_directive ccs_directives[CCS_MAX_DIRECTIVE_INDEX] = {
 	[CCS_DIRECTIVE_ACL_GROUP_253] = { "acl_group 253", NULL, 0, 0 },
 	[CCS_DIRECTIVE_ACL_GROUP_254] = { "acl_group 254", NULL, 0, 0 },
 	[CCS_DIRECTIVE_ACL_GROUP_255] = { "acl_group 255", NULL, 0, 0 },
+	[CCS_DIRECTIVE_ADDRESS_GROUP] = { "address_group", NULL, 0, 0 },
 	[CCS_DIRECTIVE_AGGREGATOR]    = { "aggregator", NULL, 0, 0 },
+	[CCS_DIRECTIVE_CAPABILITY]    = { "capability", NULL, 0, 0 },
+	[CCS_DIRECTIVE_DENY_AUTOBIND] = { "deny_autobind", NULL, 0, 0 },
 	[CCS_DIRECTIVE_FILE_APPEND]   = { "file append", NULL, 0, 0 },
 	[CCS_DIRECTIVE_FILE_CHGRP]    = { "file chgrp", NULL, 0, 0 },
 	[CCS_DIRECTIVE_FILE_CHMOD]    = { "file chmod", NULL, 0, 0 },
@@ -309,7 +312,11 @@ struct ccs_editpolicy_directive ccs_directives[CCS_MAX_DIRECTIVE_INDEX] = {
 	[CCS_DIRECTIVE_FILE_WRITE]    = { "file write", NULL, 0, 0 },
 	[CCS_DIRECTIVE_INITIALIZE_DOMAIN]
 	= { "initialize_domain", NULL, 0, 0 },
+	[CCS_DIRECTIVE_IPC_SIGNAL]    = { "ipc signal", NULL, 0, 0 },
 	[CCS_DIRECTIVE_KEEP_DOMAIN]   = { "keep_domain", NULL, 0, 0 },
+	[CCS_DIRECTIVE_MISC_ENV]      = { "misc env", NULL, 0, 0 },
+	[CCS_DIRECTIVE_NETWORK_INET]  = { "network inet", NULL, 0, 0 },
+	[CCS_DIRECTIVE_NETWORK_UNIX]  = { "network unix", NULL, 0, 0 },
 	[CCS_DIRECTIVE_NONE]          = { "", NULL, 0, 0 },
 	[CCS_DIRECTIVE_NO_INITIALIZE_DOMAIN]
 	= { "no_initialize_domain", NULL, 0, 0 },
@@ -319,6 +326,14 @@ struct ccs_editpolicy_directive ccs_directives[CCS_MAX_DIRECTIVE_INDEX] = {
 	[CCS_DIRECTIVE_PATH_GROUP]    = { "path_group", NULL, 0, 0 },
 	[CCS_DIRECTIVE_QUOTA_EXCEEDED] = { "quota_exceeded", NULL, 0, 0 },
 	[CCS_DIRECTIVE_RESET_DOMAIN]  = { "reset_domain", NULL, 0, 0 },
+	[CCS_DIRECTIVE_TASK_AUTO_DOMAIN_TRANSITION]
+	= { "task auto_domain_transition", NULL, 0, 0 },
+	[CCS_DIRECTIVE_TASK_AUTO_EXECUTE_HANDLER]
+	= { "task auto_execute_handler", NULL, 0, 0 },
+	[CCS_DIRECTIVE_TASK_DENIED_EXECUTE_HANDLER]
+	= { "task denied_execute_handler", NULL, 0, 0 },
+	[CCS_DIRECTIVE_TASK_MANUAL_DOMAIN_TRANSITION]
+	= { "task manual_domain_transition", NULL, 0, 0 },
 	[CCS_DIRECTIVE_TRANSITION_FAILED]
 	= { "transition_failed", NULL, 0, 0 },
 	[CCS_DIRECTIVE_USE_GROUP]     = { "use_group", NULL, 0, 0 },
